@@ -81,9 +81,25 @@ def _patch_oauth2_client_methods():
     
     def check_client_secret(self, client_secret):
         """Validate client secret using constant-time comparison"""
+        logger.debug(f"check_client_secret called for client {self.client_id}")
+        logger.debug(f"Has client_secret attribute: {hasattr(self, 'client_secret')}")
+        
         if not self.has_client_secret():
+            logger.warning(f"Client {self.client_id} has no secret configured")
             return False
-        return secrets.compare_digest(self.client_secret, client_secret)
+        
+        stored_secret = self.client_secret
+        provided_secret = client_secret
+        
+        logger.debug(f"Stored secret length: {len(stored_secret)}")
+        logger.debug(f"Provided secret length: {len(provided_secret)}")
+        logger.debug(f"Stored secret (first 10 chars): {stored_secret[:10]}...")
+        logger.debug(f"Provided secret (first 10 chars): {provided_secret[:10]}...")
+        
+        result = secrets.compare_digest(stored_secret, provided_secret)
+        logger.debug(f"Secret comparison result: {result}")
+        
+        return result
     
     def get_client_id(self):
         """Return the client_id"""
@@ -344,8 +360,11 @@ class ModularAuthorizationServer(AuthorizationServer):
     
     def query_client(self, client_id: str):
         """Implements the mandatory client query for Authlib."""
+        logger.debug(f"query_client called with client_id: {client_id}")
+        
         OAuth2Client = _get_model('OAuth2Client')
         if not OAuth2Client:
+            logger.error("OAuth2Client model not found in registry")
             return None
         
         with db_service.session_scope() as session:
@@ -353,6 +372,10 @@ class ModularAuthorizationServer(AuthorizationServer):
             if client:
                 session.expunge(client)
                 logger.debug(f"Found client: {client_id}")
+                logger.debug(f"Client name: {getattr(client, 'client_name', 'N/A')}")
+                logger.debug(f"Client has secret: {bool(getattr(client, 'client_secret', None))}")
+                logger.debug(f"Client auth method: {getattr(client, 'token_endpoint_auth_method', 'N/A')}")
+                logger.debug(f"Client is_active: {getattr(client, 'is_active', 'N/A')}")
             else:
                 logger.warning(f"Client not found: {client_id}")
             return client
@@ -394,6 +417,22 @@ class ModularAuthorizationServer(AuthorizationServer):
         This is required by Authlib but was not implemented, causing NotImplementedError.
         """
         return status_code, payload, headers
+    
+    def send_signal(self, name, *args, **kwargs):
+        """
+        Send a signal/event notification.
+        
+        Authlib uses this for hooks like 'after_authenticate_client'.
+        We don't need to do anything with signals for basic OAuth,
+        but the method must exist to avoid NotImplementedError.
+        
+        Args:
+            name: Signal name (e.g., 'after_authenticate_client')
+            *args, **kwargs: Signal-specific arguments
+        """
+        logger.debug(f"Signal sent: {name}")
+        # Signals are optional - we don't need to do anything
+        pass
 
     def create_oauth2_request(self, request):
         """
